/******************************************************************
 *
 * Name:	AL_procs.c
 * 
 * Description:
 * 
 * Author:	Tomasz Stachowiak
 *
 * Date:	20/07/96
 *
 * Change Log:
 *
 ********************************************************************/

#include <stdio.h>
#include <dmedia/audio.h>

#include "AudioParams.h"

ALport micro, speaker;		    /* audio variables */
ALconfig conf;

/***********************************************************************
 *
 * Audio initializations and closings
 *
 **********************************************************************/
void SetRate(long rate)
  {
     long buf[4];

     buf[0] = AL_INPUT_RATE;
     buf[1] = rate;
     buf[2] = AL_OUTPUT_RATE;
     buf[3] = rate;

     ALsetparams(AL_DEFAULT_DEVICE, buf, 4);
  }

void InitSpeaker()
{
  SetRate(RATE);

  if ((conf = ALnewconfig()) == 0)
    fprintf (stderr, "Config allocation error\n");
  if (ALsetchannels(conf, MONO) < 0)
    fprintf (stderr, "Setting channel error\n");
  if (ALsetqueuesize(conf, QSIZE) < 0)
    fprintf (stderr, "Setting queue size error\n");
  if (ALsetwidth(conf, AL_SAMPLE_16) < 0)
    fprintf (stderr, "Setting sample width error\n");

  if ((speaker = ALopenport("speaker", "w", conf)) == 0)
    fprintf (stderr, "Port opening error");

}

void CloseSpeaker()
{
  ALcloseport(speaker);

}

void InitMic()
{  
  SetRate(RATE);

  if ((conf = ALnewconfig()) == 0)
    fprintf (stderr, "Config allocation error\n");
  if (ALsetchannels(conf, MONO) < 0)
    fprintf (stderr, "Setting channel error\n");
  if (ALsetqueuesize(conf, QSIZE) < 0)
    fprintf (stderr, "Setting queue size error\n");
  if (ALsetwidth(conf, AL_SAMPLE_16) < 0)
    fprintf (stderr, "Setting sample width error\n");

  if ((micro = ALopenport("microphone", "r", conf)) == 0)
    fprintf (stderr, "Port opening error");
}

void CloseMic()
{
  ALcloseport(micro);
}


/*
 * Playing function
 */
void PutFrameToSpeaker(char *buf, int samples_no)
{
  ALwritesamps(speaker, buf, samples_no);
}

/*
 * Reading sound from mic.
 */
void GetFrameFromMic(char *buf, int samples_no)
{
   ALreadsamps(micro, buf, samples_no);
}


void VolumeChange(long vol)
{
  long buf[4];
  
  buf[0] = AL_LEFT_SPEAKER_GAIN;
  buf[2] = AL_LEFT_SPEAKER_GAIN;
  buf[1] = (long)(2.55*(float)vol);
  buf[3] = (long)(2.55*(float)vol);
  ALsetparams(AL_DEFAULT_DEVICE, buf, 4);
}

long GetVolume()
  {
     long buf[4];

     buf[0] = AL_LEFT_SPEAKER_GAIN;
     buf[2] = AL_LEFT_SPEAKER_GAIN;

     ALgetparams(AL_DEFAULT_DEVICE, buf, 4);
     return (long)((float)buf[1]/(float)2.55);
  }

